<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ko">
<context>
    <name>Arqiver::AboutDialog</name>
    <message>
        <location filename="../../about.ui" line="148"/>
        <source>License</source>
        <translation>라이선스</translation>
    </message>
</context>
<context>
    <name>Arqiver::Backend</name>
    <message>
        <location filename="../../backends.cpp" line="849"/>
        <source>This file is a link but its target does not exist.</source>
        <translation>이 파일은 링크이지만 대상이 없습니다.</translation>
    </message>
    <message>
        <location filename="../../backends.cpp" line="1273"/>
        <location filename="../../backends.cpp" line="1305"/>
        <location filename="../../backends.cpp" line="1349"/>
        <source>Could not read archive</source>
        <translation>압축파일을 읽을 수 없습니다</translation>
    </message>
    <message>
        <location filename="../../backends.cpp" line="1308"/>
        <location filename="../../backends.cpp" line="1354"/>
        <source>Archive Loaded</source>
        <translation>압축파일이 불러오기되었습니다</translation>
    </message>
    <message>
        <location filename="../../backends.cpp" line="1315"/>
        <location filename="../../backends.cpp" line="1402"/>
        <source>Modification Finished</source>
        <translation>수정이 완료되었습니다</translation>
    </message>
    <message>
        <location filename="../../backends.cpp" line="1336"/>
        <location filename="../../backends.cpp" line="1371"/>
        <source>Extraction Finished</source>
        <translation>압축풀기가 완료되었습니다</translation>
    </message>
    <message>
        <location filename="../../backends.cpp" line="1339"/>
        <location filename="../../backends.cpp" line="1390"/>
        <source>Extraction Failed</source>
        <translation>압축을 풀지 못했습니다</translation>
    </message>
    <message>
        <location filename="../../backends.cpp" line="1487"/>
        <source>%1 is missing from your system.
Please install it for this kind of archive!</source>
        <translation>%1이(가) 시스템에 없습니다.
이런 종류의 압축파일을 위해 설치하십시오!</translation>
    </message>
</context>
<context>
    <name>Arqiver::LineEdit</name>
    <message>
        <location filename="../../lineedit.h" line="33"/>
        <source>You could type inside the main view.
Clear text with the Escape key.</source>
        <translation>기본 보기 내부에 입력할 수 있습니다.
Esc 키를 사용하여 텍스트를 지우십시오.</translation>
    </message>
</context>
<context>
    <name>Arqiver::PrefDialog</name>
    <message>
        <location filename="../../pref.ui" line="14"/>
        <source>Preferences</source>
        <translation>기본 설정</translation>
    </message>
    <message>
        <location filename="../../pref.ui" line="50"/>
        <source>Start with this size:</source>
        <translation>이 크기로 시작:</translation>
    </message>
    <message>
        <location filename="../../pref.ui" line="118"/>
        <source>Use system icons where possible</source>
        <translation>가능한 경우 시스템 아이콘 사용</translation>
    </message>
    <message>
        <location filename="../../pref.ui" line="125"/>
        <source>Show prompt on removing items</source>
        <translation>항목 제거 시 프롬프트 표시</translation>
    </message>
    <message>
        <location filename="../../pref.ui" line="132"/>
        <source>If this is unchecked, only the top level directories will be expanded.</source>
        <translation>선택하지 않으면, 최상위 디렉토리만 펼쳐집니다.</translation>
    </message>
    <message>
        <location filename="../../pref.ui" line="135"/>
        <source>Expand all directories when opening archives</source>
        <translation>압축파일을 열 때 모든 디렉토리 펼치기</translation>
    </message>
    <message>
        <location filename="../../pref.ui" line="147"/>
        <location filename="../../pref.ui" line="160"/>
        <source>Leave empty for the default.

Warning: Arqiver will not work if the
binary does not belong to libarchive.</source>
        <translation>기본값은 비워 둡니다.

경고: 바이너리가 libarchive에 속하지
않으면 Arqiver가 작동하지 않습니다.</translation>
    </message>
    <message>
        <location filename="../../pref.ui" line="153"/>
        <source>libarchive binary:</source>
        <translation>libarchive 바이너리:</translation>
    </message>
    <message>
        <location filename="../../pref.ui" line="38"/>
        <source>Remember window &amp;size on closing</source>
        <translation>닫을 때 창 크기 기억</translation>
    </message>
    <message>
        <location filename="../../pref.ui" line="93"/>
        <source>Size of view icons:</source>
        <translation>보기 아이콘 크기:</translation>
    </message>
    <message>
        <location filename="../../pref.cpp" line="56"/>
        <source>px</source>
        <translation>px</translation>
    </message>
    <message>
        <location filename="../../pref.cpp" line="178"/>
        <source>Application restart is needed for changes to take effect.</source>
        <translation>변경사항을 적용하려면 응용 프로그램을 다시 시작해야 합니다.</translation>
    </message>
    <message>
        <location filename="../../pref.cpp" line="235"/>
        <source>Select libarchive binary</source>
        <translation>라이브러리 바이너리 선택</translation>
    </message>
</context>
<context>
    <name>Arqiver::mainWin</name>
    <message>
        <location filename="../../mainWin.ui" line="53"/>
        <source>Archive:</source>
        <translation>압축파일:</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="106"/>
        <source>Filter Files...</source>
        <translation>파일 필터링...</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="129"/>
        <source>&amp;File</source>
        <translation>파일(&amp;F)</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="140"/>
        <source>&amp;Edit</source>
        <translation>편집(&amp;E)</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="155"/>
        <source>&amp;View</source>
        <translation>보기(&amp;V)</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="166"/>
        <source>&amp;Help</source>
        <translation>도움말(&amp;H)</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="204"/>
        <source>&amp;Open Archive</source>
        <translation>압축파일 열기(&amp;O)</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="207"/>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="212"/>
        <source>&amp;New Archive</source>
        <translation>새 압축파일 만들기(&amp;N)</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="215"/>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="220"/>
        <source>&amp;Quit</source>
        <translation>종료(&amp;Q)</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="223"/>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="228"/>
        <source>Add File(s)</source>
        <translation>파일 추가</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="233"/>
        <source>Remove File(s)</source>
        <translation>파일 제거</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="238"/>
        <source>Extract All</source>
        <translation>모두 압축풀기</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="241"/>
        <source>Ctrl+E</source>
        <translation>Ctrl+E</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="246"/>
        <source>Add Directory</source>
        <translation>디렉터리 추가</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="251"/>
        <source>Extract Selection</source>
        <translation>선택 항목 압축풀기</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="256"/>
        <source>Set Password</source>
        <translation>비밀번호 설정</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="261"/>
        <source>E&amp;xpand</source>
        <translation>펼치기(&amp;X)</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="264"/>
        <source>Ctrl+Shift+Down</source>
        <translation>Ctrl+Shift+Down</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="269"/>
        <source>Collap&amp;se</source>
        <translation>접기</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="272"/>
        <source>Ctrl+Shift+Up</source>
        <translation>Ctrl+Shift+Up</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="277"/>
        <source>&amp;About</source>
        <translation>정보(&amp;A)</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="282"/>
        <source>&amp;Copy Current Path</source>
        <translation>현재 경로 복사(&amp;C)</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="287"/>
        <source>&amp;Preferences</source>
        <translation>기본 설정(&amp;P)</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="292"/>
        <source>Stop &amp;Process</source>
        <translation>프로세스 중지(&amp;P)</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="295"/>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="305"/>
        <source>Update Archive</source>
        <translation>압축파일 업데이트</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="149"/>
        <source>Root</source>
        <translation>루트</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="254"/>
        <source>Error</source>
        <translation>오류</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="325"/>
        <source>File</source>
        <translation>파일</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="325"/>
        <source>MimeType</source>
        <translation>MIME유형</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="325"/>
        <source>Size</source>
        <translation>크기</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="554"/>
        <location filename="../../mainWin.cpp" line="839"/>
        <location filename="../../mainWin.cpp" line="882"/>
        <source>Opening Archive...</source>
        <translation>압축파일 여는 중...</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="768"/>
        <source>Create Archive</source>
        <translation>압축파일 만들기</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="465"/>
        <location filename="../../mainWin.cpp" line="794"/>
        <location filename="../../mainWin.cpp" line="996"/>
        <location filename="../../mainWin.cpp" line="1307"/>
        <source>Question</source>
        <translation>질문</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="795"/>
        <source>The following archive already exists:</source>
        <translation>다음 압축파일이 이미 존재합니다:</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="797"/>
        <source>Do you want to replace it?
</source>
        <translation>교체하시겠습니까?
</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="831"/>
        <source>Open Archive</source>
        <translation>압축파일 열기</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="897"/>
        <location filename="../../mainWin.cpp" line="904"/>
        <location filename="../../mainWin.cpp" line="945"/>
        <source>Add to Archive</source>
        <translation>압축파일에 추가</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="940"/>
        <location filename="../../mainWin.cpp" line="971"/>
        <location filename="../../mainWin.cpp" line="1254"/>
        <location filename="../../mainWin.cpp" line="1260"/>
        <source>Adding Items...</source>
        <translation>항목 추가 중...</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="997"/>
        <source>Do you want to remove the selected item(s)?
</source>
        <translation>선택한 항목을 제거하시겠습니까?
</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="1016"/>
        <source>Removing Items...</source>
        <translation>항목 제거 중...</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="1217"/>
        <location filename="../../mainWin.cpp" line="1232"/>
        <location filename="../../mainWin.cpp" line="1322"/>
        <location filename="../../mainWin.cpp" line="1336"/>
        <source>Extracting...</source>
        <translation>압축 푸는 중...</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="1060"/>
        <source>Copy Archive Path</source>
        <translation>압축파일 경로 복사</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="466"/>
        <source>Some files have been modified.</source>
        <translation>일부 파일이 수정되었습니다.</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="467"/>
        <source>Do you want to ignore the changes?
</source>
        <translation>변경사항을 무시하시겠습니까?
</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="628"/>
        <source>All Types</source>
        <translation>모든 유형</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="638"/>
        <location filename="../../mainWin.cpp" line="662"/>
        <source>Uncompressed Archive</source>
        <translation>압축되지 않은 압축파일</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="639"/>
        <location filename="../../mainWin.cpp" line="663"/>
        <source>GZip Compressed Archive</source>
        <translation>GZip 압축된 압축파일</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="640"/>
        <location filename="../../mainWin.cpp" line="664"/>
        <location filename="../../mainWin.cpp" line="665"/>
        <source>BZip Compressed Archive</source>
        <translation>BZip 압축된 압축파일</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="641"/>
        <location filename="../../mainWin.cpp" line="666"/>
        <source>BZip2 Compressed Archive</source>
        <translation>BZip2 압축된 압축파일</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="642"/>
        <location filename="../../mainWin.cpp" line="674"/>
        <source>LMZA Compressed Archive</source>
        <translation>LMZA 압축된 압축파일</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="643"/>
        <location filename="../../mainWin.cpp" line="671"/>
        <source>XZ Compressed Archive</source>
        <translation>XZ 압축된 압축파일</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="644"/>
        <location filename="../../mainWin.cpp" line="675"/>
        <source>Zstandard Compressed Archive</source>
        <translation>Zstandard 압축된 압축파일</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="645"/>
        <location filename="../../mainWin.cpp" line="677"/>
        <source>CPIO Archive</source>
        <translation>CPIO 압축파일</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="647"/>
        <location filename="../../mainWin.cpp" line="679"/>
        <source>AR Archive</source>
        <translation>AR 압축파일</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="649"/>
        <location filename="../../mainWin.cpp" line="681"/>
        <source>Zip Archive</source>
        <translation>Zip 압축파일</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="650"/>
        <location filename="../../mainWin.cpp" line="683"/>
        <source>Gzip Archive</source>
        <translation>Gzip 압축파일</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="651"/>
        <location filename="../../mainWin.cpp" line="682"/>
        <source>7-Zip Archive</source>
        <translation>7-Zip 압축파일</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="667"/>
        <location filename="../../mainWin.cpp" line="668"/>
        <source>READ-ONLY: BZip Archive</source>
        <translation>읽기 전용: BZip 압축파일</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="669"/>
        <source>READ-ONLY: BZip2 Archive</source>
        <translation>읽기 전용: BZip2 압축파일</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="670"/>
        <source>READ-ONLY: BZip2 Compressed PDF Document</source>
        <translation>읽기전용: BZip2 압축된 PDF 문서</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="672"/>
        <source>READ-ONLY: XZ archive</source>
        <translation>읽기전용: XZ 압축파일</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="673"/>
        <source>READ-ONLY: XZ Compressed PDF Document</source>
        <translation>읽기전용: XZ 압축된 PDF 문서</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="676"/>
        <source>READ-ONLY: Zstandard archive</source>
        <translation>읽기전용: Zstandard 압축파일</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="684"/>
        <source>Gzip Compressed PDF Document</source>
        <translation>Gzip 압축된 PDF 문서</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="685"/>
        <source>READ-ONLY: Compressed SVG Image</source>
        <translation>읽기전용: 압축된 SVG 이미지</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="686"/>
        <location filename="../../mainWin.cpp" line="687"/>
        <location filename="../../mainWin.cpp" line="688"/>
        <location filename="../../mainWin.cpp" line="689"/>
        <source>READ-ONLY: ISO Image</source>
        <translation>읽기전용: ISO 이미지</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="690"/>
        <source>READ-ONLY: XAR Archive</source>
        <translation>읽기전용: XAR 압축파일</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="691"/>
        <source>READ-ONLY: Java Archive</source>
        <translation>읽기전용: Java 압축파일</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="692"/>
        <source>READ-ONLY: Debian Package</source>
        <translation>읽기전용: 데비안 패키지</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="693"/>
        <location filename="../../mainWin.cpp" line="694"/>
        <source>READ-ONLY: RedHat Package</source>
        <translation>읽기전용: 레드햇 패키지</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="695"/>
        <location filename="../../mainWin.cpp" line="696"/>
        <location filename="../../mainWin.cpp" line="697"/>
        <source>READ-ONLY: MS Windows Executable</source>
        <translation>읽기전용: MS Windows 실행파일</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="698"/>
        <source>READ-ONLY: MS Windows Installer Package</source>
        <translation>읽기전용: MS Windows 설치도구 패키지</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="699"/>
        <source>READ-ONLY: MS Windows Cabinet Archive</source>
        <translation>읽기전용: MS Windows 캐비닛 압축파일</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="700"/>
        <source>READ-ONLY: ACE archive</source>
        <translation>읽기전용: ACE 압축파일</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="701"/>
        <source>READ-ONLY: Android Package</source>
        <translation>읽기전용: Android 패키지</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="702"/>
        <source>READ-ONLY: RAR Archive</source>
        <translation>읽기전용: RAR 압축파일</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="703"/>
        <source>READ-ONLY: AppImage application bundle</source>
        <translation>읽기전용: AppImage 응용프로그램 번들</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="704"/>
        <source>READ-ONLY: VirtualBox Extension Pack</source>
        <translation>읽기전용: VirtualBox 확장 팩</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="713"/>
        <source>All Known Types</source>
        <translation>모든 알려진 유형</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="718"/>
        <source>Show All Files</source>
        <translation>모든 파일 표시</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="1070"/>
        <source>Open Containing Folder</source>
        <translation>포함하는 폴더 열기</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="300"/>
        <source>View Current Item</source>
        <translation>현재 항목 보기</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="1113"/>
        <location filename="../../mainWin.cpp" line="1121"/>
        <source>Enter Password</source>
        <translation>비밀번호 입력</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="1129"/>
        <source>Cancel</source>
        <translation>취소</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="1134"/>
        <source>OK</source>
        <translation>확인</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="1138"/>
        <source>Encrypt the file list</source>
        <translation>파일 목록 암호화</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="1139"/>
        <source>This will take effect after files/folders are added.</source>
        <translation>이것은 파일/폴더가 추가된 후에 적용됩니다.</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="1210"/>
        <location filename="../../mainWin.cpp" line="1286"/>
        <source>Extract Into Directory</source>
        <translation>디렉터리에 압축풀기</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="1308"/>
        <source>Some files will be overwritten.
Do you want to continue?
</source>
        <translation>일부 파일을 덮어씁니다.
계속하시겠습니까?
</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="1442"/>
        <source>Link To: %1</source>
        <translation>링크 대상: %1</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="1716"/>
        <source>Could not read archive</source>
        <translation>압축파일을 읽을 수 없습니다</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="1789"/>
        <source>A simple Qt archive manager</source>
        <translation>단순한 Qt 압축파일 관리자</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="1790"/>
        <source>based on libarchive, gzip and 7z</source>
        <translation>libarchive, gzip 및 7z 기반함</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="1791"/>
        <source>Author</source>
        <translation>개발자</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="1792"/>
        <source>aka.</source>
        <translation>일명.</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="1793"/>
        <location filename="../../mainWin.cpp" line="1794"/>
        <source>About Arqiver</source>
        <translation>Arqiver 정보</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="1793"/>
        <source>Translators</source>
        <translation>번역자</translation>
    </message>
</context>
</TS>
